VG_VaR <- function(r, mu, sigma2, gammap, nu, level, nreps)
  
# computing dynamic VaR via Monte Carlo simulation for variance-gamma distributed observations;
# observations are first cleaned via a GARCH(1,1) filter
  
# Inputs:
  # r: (nx1) numeric vector of returns
  # mu: numerical value of mu
  # sigma2: numerical value of sigma?2
  # gamma: numerical value of gamma
  # nu: numerical value of nu
  # level: VaR level
  # nreps: number of replications

# Outputs:
  # res: ((n+1)x1) vector; the first value is the (unconditional) VaR of the filtered series 
  # r/hat{sigma}_t; the reamining n values are the dynamic VaRs.
  
# Usage:
  
  # source('VG_VaR.R')
  # res <- VG_VaR(r, 0, 0.05, -0.1, 1, 0.05, 1000)
  # VaRMCECMdyn1 <- res[[2]]

{
require(ghyp)  
require(fGarch)
garchRes <- garchFit(formula = ~ garch(1, 1), r, cond.dist = "QMLE", include.mean = F) # filter data
estVol <- garchRes@sigma.t
Z <- r/estVol
vg_d = VG(lambda = nu, psi = 2*nu , mu = mu, sigma = sqrt(sigma2), gamma = gammap)
ysimVG = rghyp(nreps, object = vg_d)
VaRVG <- quantile(ysimVG,lev)
VaRVGdyn <- estVol*VaRVG
res <- list(VaRVG,VaRVGdyn)
res
}  